@@ -7,6 +7,7 @@
 # @Desc    :   None
 
 
+import hashlib
 import zipfile
 import numpy as np
 import _pickle as cPickle
@@ -34,4 +35,21 @@ def mmdt_std(md):
     std_main_values.pop(std_main_values.index(min(std_main_values)))
     #求标准差
     arr_std = np.std(std_main_values, ddof=1)
-    return arr_std
\ No newline at end of file
+    return arr_std
+
+# 生成md5
+def gen_md5(file_name):
+    with open(file_name, 'rb') as f:
+        s = f.read()
+        _m = hashlib.md5()
+        _m.update(s)
+        return _m.hexdigest()
+
+
+# 生成sha1
+def gen_sha1(file_name):
+    with open(file_name, 'rb') as f:
+        s = f.read()
+        _s = hashlib.sha1()
+        _s.update(s)
+        return _s.hexdigest()
